ask_input — Simple data input in Rust
This library makes terminal input in Rust as easy and convenient as it is in Python. One single generic function to handle all your input needs with automatic stdout flushing.
Quick Start
use ask_input::input;
let age: i32 = input().unwrap();
println!("You are {} years old", age);
let name: String = input().unwrap();
println!("Hello, {}!", name);Functions
- input
- Reads a line from stdin, flushes stdout automatically, and parses it into the target type.